==> tmap-1.0.1.tar.gz: tmap-1.0.1/setup.py <==
from setuptools import setup, find_packages

setup(name='tmap',
      version='1.0.1',
      description='A topological data analysis framework implementing the TDA Mapper algorithm for population-scale microbiome data analysis ',
      author='Haokui Zhou, Tianhua Liao',
      author_email='zhouhaokui@hotmail.com',
      license='GNU',
      url='https://github.com/GPZ-Bioinfo/tmap',
      packages=find_packages(),
      package_data={'': ['test_data/*.csv',
                         'test_data/*.tsv',
                         'example/*'],
                    },
      scripts=['tmap/api/envfit_analysis.py',
               'tmap/api/Network_generator.py',
               'tmap/api/SAFE_analysis.py',
               'tmap/api/SAFE_visualization.py'],
      install_requires=['statsmodels>=0.9.0',
                        'tqdm',
                        'scikit-learn>=0.19.1',
                        'matplotlib>=2.2.2',
                        'networkx>=2.1',
                        'pandas>=0.23.0',
                        'scipy',
                        'matplotlib!=3.0.0rc2',
                        'umap-learn',
                        'scikit-bio>=0.5.2',
                        'numpy<1.14.0,>=1.9.2',
                        'rpy2',
                        'plotly'
                        ],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
          "Operating System :: OS Independent",
          "Topic :: Scientific/Engineering :: Bio-Informatics",
      ],
      zip_safe=False,
      )

==> tmap-1.0.2.tar.gz: tmap-1.0.2/setup.py <==
from setuptools import setup, find_packages

setup(name='tmap',
      version='1.0.2',
      description='A topological data analysis framework implementing the TDA Mapper algorithm for population-scale microbiome data analysis ',
      author='Haokui Zhou, Tianhua Liao',
      author_email='zhouhaokui@hotmail.com',
      license='GNU',
      url='https://github.com/GPZ-Bioinfo/tmap',
      packages=find_packages(),
      package_data={'': ['test_data/*.csv',
                         'test_data/*.tsv',
                         'example/*'],
                    },
      scripts=['tmap/api/envfit_analysis.py',
               'tmap/api/Network_generator.py',
               'tmap/api/SAFE_analysis.py',
               'tmap/api/SAFE_visualization.py',
               'tmap/api/quick_vis.py'],
      install_requires=['scikit-bio>=0.5.2',
                        'statsmodels>=0.9.0',
                        'tqdm',
                        'scikit-learn>=0.19.1',
                        'matplotlib>=2.2.2',
                        'networkx>=2.1',
                        'pandas>=0.23.0',
                        'scipy',
                        'matplotlib!=3.0.0rc2',
                        'umap-learn',
                        'numpy<1.14.0,>=1.9.2',
                        'rpy2',
                        'plotly',
                        ],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
          "Operating System :: OS Independent",
          "Topic :: Scientific/Engineering :: Bio-Informatics",
      ],
      zip_safe=False,
      )
